import javax.persistence.*;
import java.util.*;

public class TestClient {
  @PersistenceUnit private static EntityManagerFactory emf;
  public static void main(String[] args) throws Exception {
    if(emf == null) {
      emf = Persistence.createEntityManagerFactory("pu1");
    }
    EntityManager em = emf.createEntityManager();

    Customer cust = new Customer();
    cust.setFirstName("Bill");
    cust.setLastName("Burke");
    cust.setBaseCustomer(1);
    int pk = createCustomer(em, cust);

    cust = findCustomer(em, pk);
    cust.setFirstName("Billy");
    doMerge(em, cust);
    doFlush(em, cust.getId());
    doRemove(em, cust.getId());

    em.close();
  }

   public static int createCustomer(EntityManager manager, Customer cust)
   {
      System.out.println("--------------------------------------");
      System.out.println("Calling createCustomer():" + cust.getFirstName());
      System.out.println("Calling manager.persist()");
      manager.getTransaction().begin();
      manager.persist(cust);
      manager.getTransaction().commit();
      System.out.println("Ending createCustomer.");
      return cust.getId();
   }

 
   public static Customer findCustomer(EntityManager manager, int pKey)
   {
      System.out.println("--------------------------------------");
      System.out.println("Calling findCustomer()");
      System.out.println("manager.find()");
      Customer cust = manager.find(Customer.class, pKey);
      System.out.println("Returning from findCustomer(): " + cust.getFirstName());
      return cust;
   }



   public static void doMerge(EntityManager manager, Customer cust)
   {
      System.out.println("--------------------------------------");
      System.out.println("Calling doMerge()");
      manager.getTransaction().begin();
      manager.merge(cust);
      manager.getTransaction().commit();
      System.out.println("Returning from doMerge()");
   }

   public static void doFlush(EntityManager manager, int pKey)
   {
      System.out.println("--------------------------------------");
      System.out.println("Calling doFlush()");
      System.out.println("manager.find()");
      Customer cust = manager.find(Customer.class, pKey);
      System.out.println("cust.setName()");
      cust.setFirstName("doFlush");
      System.out.println("calling manager.flush()");
      manager.getTransaction().begin();
      manager.flush();
      manager.getTransaction().commit();
      System.out.println("returning from doFlush()");
   }

   public static void doRemove(EntityManager manager, int pKey)
   {
      System.out.println("--------------------------------------");
      System.out.println("Calling doRemove()");
      System.out.println("manager.find()");
      Customer cust = manager.find(Customer.class, pKey);
      System.out.println("calling manager.remove()");
      manager.getTransaction().begin();
      manager.remove(cust);
      manager.getTransaction().commit();
      System.out.println("returning from doRemove()");
   }

}




